==> haskell-lifted-async-0.10.0.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.4
id: lifted-async-0.10.0.4-G7dWD7XWmaVJVApBRz0zbF
key: lifted-async-0.10.0.4-G7dWD7XWmaVJVApBRz0zbF
license: BSD-3-Clause
copyright: Copyright (C) 2012-2019 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <me@maoe.name>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: 21c863ccbcb199b6dbf88477d6c77b97
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-async-0.10.0.4
hs-libraries: HSlifted-async-0.10.0.4-G7dWD7XWmaVJVApBRz0zbF
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    constraints-0.11-1mpDQajVxfT7QBTxc1wX3l
    lifted-base-0.2.3.12-8U026HQXq6a80e31EPyHzq
    monad-control-1.0.2.3-HrYPbjEu44jLedbHP7C2CP
    transformers-base-0.4.5.2-AKjzOvjUCFd4YE2ZLG0MGC
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.0.4-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.10.0.4
id: lifted-async-0.10.0.4-D1NcmIwNQV29vx2eh6Q200
key: lifted-async-0.10.0.4-D1NcmIwNQV29vx2eh6Q200
license: BSD-3-Clause
copyright: Copyright (C) 2012-2019 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <me@maoe.name>
author: Mitsutoshi Aoe
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
abi: 1ec1a2736b06bcab52040471cc180464
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
import-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/lifted-async-0.10.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lifted-async-0.10.0.4
hs-libraries: HSlifted-async-0.10.0.4-D1NcmIwNQV29vx2eh6Q200
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    constraints-0.11-G3IgqmRTjjF558ETjsc7Xv
    lifted-base-0.2.3.12-HS16xPOcy5B1xgzprPVI1H
    monad-control-1.0.2.3-JMF7teit9M6FKdrQm56I9R
    transformers-base-0.4.5.2-or9mqY8NTvHJLsZFWJxI7
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
